#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONHEARTBEATWARNING 2
#define ONRSPSUBSCRIBEFLOWCTRLWARNING 3
#define ONRSPUNSUBSCRIBEFLOWCTRLWARNING 4
#define ONRSPAUTHENTICATE 5
#define ONRSPUSERLOGIN 6
#define ONRSPUSERLOGOUT 7
#define ONRSPORDERINSERT 8
#define ONRSPORDERACTION 9
#define ONRSPMKBATCHORDERACTION 10
#define ONRSPEXECORDERINSERT 11
#define ONRSPEXECORDERACTION 12
#define ONRSPFORQUOTEINSERT 13
#define ONRSPQUOTEINSERT 14
#define ONRSPQUOTEACTION 15
#define ONRSPBATCHORDERACTION 16
#define ONRSPOPTIONSELFCLOSEINSERT 17
#define ONRSPOPTIONSELFCLOSEACTION 18
#define ONRSPCOMBACTIONINSERT 19
#define ONRSPQRYORDER 20
#define ONRSPQRYTRADE 21
#define ONRSPQRYINVESTORPOSITION 22
#define ONRSPQRYTRADINGACCOUNT 23
#define ONRSPQRYINVESTOR 24
#define ONRSPQRYTRADINGCODE 25
#define ONRSPQRYINSTRUMENTMARGINRATE 26
#define ONRSPQRYINSTRUMENTCOMMISSIONRATE 27
#define ONRSPQRYEXCHANGE 28
#define ONRSPQRYPRODUCT 29
#define ONRSPQRYINSTRUMENT 30
#define ONRSPQRYCOMBINSTRUMENT 31
#define ONRSPQRYCOMBACTION 32
#define ONRSPQRYINVESTORPOSITIONFORCOMB 33
#define ONRSPQRYDEPTHMARKETDATA 34
#define ONRSPQRYINSTRUMENTSTATUS 35
#define ONRSPQRYINVESTORPOSITIONDETAIL 36
#define ONRSPQRYEXCHANGEMARGINRATE 37
#define ONRSPQRYEXCHANGEMARGINRATEADJUST 38
#define ONRSPQRYOPTIONINSTRTRADECOST 39
#define ONRSPQRYOPTIONINSTRCOMMRATE 40
#define ONRSPQRYEXECORDER 41
#define ONRSPQRYFORQUOTE 42
#define ONRSPQRYFORQUOTEPARAM 43
#define ONRSPQRYINVESTORPRODSPBMDETAIL 44
#define ONRSPQRYTRADEROFFER 45
#define ONRSPQRYQUOTE 46
#define ONRSPQRYOPTIONSELFCLOSE 47
#define ONRSPERROR 48
#define ONRTNORDER 49
#define ONRTNTRADE 50
#define ONERRRTNORDERINSERT 51
#define ONERRRTNORDERACTION 52
#define ONRTNINSTRUMENTSTATUS 53
#define ONRTNEXECORDER 54
#define ONERRRTNEXECORDERINSERT 55
#define ONERRRTNEXECORDERACTION 56
#define ONERRRTNFORQUOTEINSERT 57
#define ONRTNQUOTE 58
#define ONERRRTNQUOTEINSERT 59
#define ONERRRTNQUOTEACTION 60
#define ONRTNFORQUOTERSP 61
#define ONERRRTNBATCHORDERACTION 62
#define ONRTNOPTIONSELFCLOSE 63
#define ONERRRTNOPTIONSELFCLOSEINSERT 64
#define ONERRRTNOPTIONSELFCLOSEACTION 65
#define ONRTNCOMBACTION 66
#define ONRSPQRYINSTRUMENTORDERCOMMRATE 67
#define ONRTNFLOWCTRLWARNING 68
